==> ldaptive-1.0.13-sources.jar: org/ldaptive/asn1/DN.java <==
/*
  $Id: DN.java 3189 2016-11-01 21:21:43Z daniel_fisher $

  Copyright (C) 2003-2014 Virginia Tech.
  All rights reserved.

  SEE LICENSE FOR MORE INFORMATION

  Author:  Middleware Services
  Email:   middleware@vt.edu
  Version: $Revision: 3189 $
  Updated: $Date: 2016-11-01 17:21:43 -0400 (Tue, 01 Nov 2016) $
*/
package org.ldaptive.asn1;

import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import org.ldaptive.LdapUtils;

/**
 * A sequence of RDN values.
 *
 * @author  Middleware Services
 * @version  $Revision: 3189 $ $Date: 2016-11-01 17:21:43 -0400 (Tue, 01 Nov 2016) $
 */
public class DN implements DEREncoder
{

  /** hash code seed. */
  private static final int HASH_CODE_SEED = 631;

  /** RDNs in this RDN sequence. */
  private final RDN[] rdns;


  /**
   * Creates a new DN.
   *
   * @param  names  RDNs in this sequence
   */
  public DN(final Collection<RDN> names)
  {
    rdns = names.toArray(new RDN[names.size()]);
  }


  /**
   * Creates a new DN.
   *
   * @param  names  RDNs in this sequence
   */
  public DN(final RDN... names)
  {
    rdns = names;
  }


  /**
   * Returns the RDNs in this DN.
   *
   * @return  RDNs
   */
  public RDN[] getRDNs()
  {
    return rdns;
  }


  /** {@inheritDoc} */
  @Override
  public byte[] encode()
  {
    final List<DEREncoder> typeEncoders = new ArrayList<DEREncoder>();
    for (final RDN rdn : rdns) {
      typeEncoders.add(
        new DEREncoder() {
          @Override
          public byte[] encode()
          {
            return rdn.encode();
          }
        });
    }

    final ConstructedDEREncoder se = new ConstructedDEREncoder(
      UniversalDERTag.SEQ,
      typeEncoders.toArray(new DEREncoder[typeEncoders.size()]));
    return se.encode();
  }


  /**
   * Converts bytes in the buffer to a DN by reading from the current position
   * to the limit.
   *
   * @param  encoded  buffer containing DER-encoded data where the buffer is
   * positioned at the tag of the DN and the limit is set beyond the last byte
   * of DN data.
   *
   * @return  decoded bytes as a DN
   */
  public static DN decode(final ByteBuffer encoded)
  {
    return new DN(RDN.decode(encoded));
  }


  /** {@inheritDoc} */
  @Override
  public boolean equals(final Object o)
  {
    if (o == this) {
      return true;
    }
    if (o instanceof DN) {
      final DN v = (DN) o;
      return LdapUtils.areEqual(rdns, v.rdns);
    }
    return false;
  }


  /** {@inheritDoc} */
  @Override
  public int hashCode()
  {
    return LdapUtils.computeHashCode(HASH_CODE_SEED, (Object) rdns);
  }


  /** {@inheritDoc} */
  @Override
  public String toString()
  {
    return
      String.format(
        "[%s@%d::rdns=%s]",
        getClass().getName(),
        hashCode(),
        Arrays.toString(rdns));
  }
}

==> ldaptive-1.2.1-sources.jar: org/ldaptive/asn1/DN.java <==
/* See LICENSE for licensing and NOTICE for copyright. */
package org.ldaptive.asn1;

import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import org.ldaptive.LdapUtils;

/**
 * A sequence of RDN values.
 *
 * @author  Middleware Services
 */
public class DN implements DEREncoder
{

  /** hash code seed. */
  private static final int HASH_CODE_SEED = 631;

  /** RDNs in this RDN sequence. */
  private final RDN[] rdns;


  /**
   * Creates a new DN.
   *
   * @param  names  RDNs in this sequence
   */
  public DN(final Collection<RDN> names)
  {
    rdns = names.toArray(new RDN[names.size()]);
  }


  /**
   * Creates a new DN.
   *
   * @param  names  RDNs in this sequence
   */
  public DN(final RDN... names)
  {
    rdns = names;
  }


  /**
   * Returns the RDNs in this DN.
   *
   * @return  RDNs
   */
  public RDN[] getRDNs()
  {
    return rdns;
  }


  @Override
  public byte[] encode()
  {
    final List<DEREncoder> typeEncoders = new ArrayList<>();
    for (final RDN rdn : rdns) {
      typeEncoders.add(rdn::encode);
    }

    final ConstructedDEREncoder se = new ConstructedDEREncoder(
      UniversalDERTag.SEQ,
      typeEncoders.toArray(new DEREncoder[typeEncoders.size()]));
    return se.encode();
  }


  /**
   * Converts bytes in the buffer to a DN by reading from the current position to the limit.
   *
   * @param  encoded  buffer containing DER-encoded data where the buffer is positioned at the tag of the DN and the
   *                  limit is set beyond the last byte of DN data.
   *
   * @return  decoded bytes as a DN
   */
  public static DN decode(final ByteBuffer encoded)
  {
    return new DN(RDN.decode(encoded));
  }


  @Override
  public boolean equals(final Object o)
  {
    if (o == this) {
      return true;
    }
    if (o instanceof DN) {
      final DN v = (DN) o;
      return LdapUtils.areEqual(rdns, v.rdns);
    }
    return false;
  }


  @Override
  public int hashCode()
  {
    return LdapUtils.computeHashCode(HASH_CODE_SEED, (Object) rdns);
  }


  @Override
  public String toString()
  {
    return String.format("[%s@%d::rdns=%s]", getClass().getName(), hashCode(), Arrays.toString(rdns));
  }
}
